@@ -156,7 +156,7 @@
 % Copyright (C) 2008 Wellcome Trust Centre for Neuroimaging
 
 % Will Penny, Nelson Trujillo-Barreto and Lee Harrison
-% $Id: spm_spm_vb.m 4185 2011-02-01 18:46:18Z guillaume $
+% $Id: spm_spm_vb.m 4637 2012-02-02 13:15:45Z guillaume $
 
 
 %-Get SPM.mat if necessary
@@ -167,6 +167,14 @@ if ~nargin
     SPM.swd = swd;
 end
 
+%-Change to SPM.swd if specified
+%-----------------------------------------------------------------------
+try
+    cd(SPM.swd);
+catch
+    SPM.swd = pwd;
+end
+
 %-Let later functions (spm_contrasts, spm_graph) know that estimation
 % was with Variational Bayes
 %-----------------------------------------------------------------------
@@ -187,22 +195,13 @@ if SPM.PPM.window
     spm('Pointer','Arrow');
 end
 
-%-Change to SPM.swd if specified
-%-----------------------------------------------------------------------
-try
-    changed_dir = pwd;
-    cd(SPM.swd);
-catch
-    changed_dir = '';
-end
-
 %-Delete files from previous analyses
 %-----------------------------------------------------------------------
 if SPM.PPM.window
-    if exist(fullfile(pwd,'mask.img'),'file') == 2
+    if exist(fullfile(SPM.swd,'mask.img'),'file') == 2
         
         str   = {'Current directory contains SPM estimation files:',...
-                 'pwd = ',pwd,...
+                 'pwd = ',SPM.swd,...
                  'Existing results will be overwritten!'};
         
         abort = spm_input(str,1,'bd','stop|continue',[1,0],1);
@@ -210,7 +209,7 @@ if SPM.PPM.window
             spm('FigName','Stats: done',Finter); spm('Pointer','Arrow');
             return
         else
-            str = sprintf('Overwriting old results\n\t (pwd = %s) ',pwd);
+            str = sprintf('Overwriting old results\n\t (pwd = %s) ',SPM.swd);
             warning(str)
             drawnow
         end
@@ -1101,12 +1100,6 @@ end
 
 fprintf('%s%30s\n',repmat(sprintf('\b'),1,30),'...done')                %-#
 
-%-Change back to initial directory
-%-----------------------------------------------------------------------
-if ~isempty(changed_dir)
-    cd(changed_dir);
-end
-
 if SPM.PPM.window
     %===================================================================
     %- E N D: Cleanup GUI
