@@ -15,7 +15,7 @@ function [f]= spm_fx_dem_pursuit(x,v,P)
 % Copyright (C) 2008 Wellcome Trust Centre for Neuroimaging
  
 % Karl Friston
-% $Id: spm_fx_dem_pursuit.m 4187 2011-02-01 20:13:57Z karl $
+% $Id: spm_fx_dem_pursuit.m 4322 2011-05-04 15:28:08Z karl $
  
 % intisaise flow (to ensure fields are aligned)
 %--------------------------------------------------------------------------
@@ -25,22 +25,20 @@ f    = x;
 %==========================================================================
 f.a  = spm_lotka_volterra(x.a,v);
  
- 
+
 % motion of target states
 %==========================================================================
  
 % target location is determined by the attractor state softmax(x.a)
 %--------------------------------------------------------------------------
-n    = length(x.a);
-p    = exp(2*x.a);
-t    = P*p/sum(p);
-f.x  = (t - x.x)/8;
+t    = P*spm_softmax(x.a,1/2);
+f.x  = (t - x.x)/2;
 
  
 % motion of oculomotor angles (attracted to target)
 %==========================================================================
 t    = atan(x.x);
-f.o  = (t - x.o)/2;
+f.o  = (t - x.o);
 
 
 
