@@ -6,7 +6,7 @@ function varargout = spm_api_erp(varargin)
 % Copyright (C) 2008 Wellcome Trust Centre for Neuroimaging
  
 % Karl Friston
-% $Id: spm_api_erp.m 4232 2011-03-07 21:01:16Z karl $
+% $Id: spm_api_erp.m 4570 2011-11-23 17:09:59Z vladimir $
  
 if nargin == 0 || nargin == 1  % LAUNCH GUI
  
@@ -83,9 +83,9 @@ end
 switch model
     case{'ERP'}, set(handles.ERP,'Value',1);
     case{'CSD'}, set(handles.ERP,'Value',2);
-    case{'SSR'}, set(handles.ERP,'Value',2);
-    case{'IND'}, set(handles.ERP,'Value',3);
-    case{'PHA'}, set(handles.ERP,'Value',4);
+    case{'SSR'}, set(handles.ERP,'Value',3);
+    case{'IND'}, set(handles.ERP,'Value',4);
+    case{'PHA'}, set(handles.ERP,'Value',5);
     otherwise
 end
 handles = ERP_Callback(hObject, eventdata, handles);
@@ -116,7 +116,7 @@ switch model
     case{'MFM'}, set(handles.model,'Value',6);
     otherwise
 end
- 
+
 % Type of model (spatial)
 %--------------------------------------------------------------------------
 % 'ECD'    - Equivalent current dipole
@@ -162,8 +162,9 @@ try, set(handles.T2, 'String', num2str(DCM.options.Tdcm(2)));        end
 try, set(handles.Hz1,'String', num2str(DCM.options.Fdcm(1)));        end
 try, set(handles.Hz2,'String', num2str(DCM.options.Fdcm(2)));        end
 try, set(handles.Rft,'String', num2str(DCM.options.Rft));            end
-try, set(handles.Nmodes,      'Value', DCM.options.Nmodes);          end
-try, set(handles.h,           'Value', DCM.options.h);               end
+try, set(handles.Nmodes,       'Value', DCM.options.Nmodes);         end
+try, set(handles.h,            'Value', ...
+        find(str2double(get(handles.h,'String')) == DCM.options.h)); end
 try, set(handles.han,         'Value', DCM.options.han);             end
 try, set(handles.D,           'Value', DCM.options.D);               end
 try, set(handles.lock,        'Value', DCM.options.lock);            end
@@ -173,6 +174,7 @@ try, set(handles.design,      'String',num2str(DCM.xU.X','%7.2f'));  end
 try, set(handles.Uname,       'String',DCM.xU.name);                 end
 try, set(handles.Sname,       'String',DCM.Sname);                   end
 try, set(handles.onset,       'String',num2str(DCM.options.onset));  end
+try, set(handles.dur,         'String',num2str(DCM.options.dur));    end
 try, set(handles.Slocation,   'String',num2str(DCM.Lpos','%4.0f'));  end
  
 % Imaging
@@ -299,7 +301,7 @@ handles.DCM.options.model     = model;
 %--------------------------------------------------------------------------
 model = get(handles.Spatial,       'String');
 model = model{get(handles.Spatial, 'Value')};
-handles.DCM.options.spatial   = model;
+handles.DCM.options.spatial  = model;
 
 handles.DCM.options.trials   = str2num(get(handles.Y1,    'String'));
 handles.DCM.options.Tdcm(1)  = str2num(get(handles.T1,    'String'));
@@ -308,8 +310,10 @@ handles.DCM.options.Fdcm(1)  = str2num(get(handles.Hz1,   'String'));
 handles.DCM.options.Fdcm(2)  = str2num(get(handles.Hz2,   'String'));
 handles.DCM.options.Rft      = str2num(get(handles.Rft,   'String'));
 handles.DCM.options.onset    = str2num(get(handles.onset, 'String'));
+handles.DCM.options.dur      = str2num(get(handles.dur,   'String'));
 handles.DCM.options.Nmodes   = get(handles.Nmodes,        'Value');
-handles.DCM.options.h        = get(handles.h,             'Value');
+detrend_val                  = str2double(get(handles.h,  'String'));
+handles.DCM.options.h        = detrend_val(get(handles.h, 'Value'));
 handles.DCM.options.han      = get(handles.han,           'Value');
 handles.DCM.options.D        = get(handles.D,             'Value');
 handles.DCM.options.lock     = get(handles.lock,          'Value');
@@ -389,13 +393,20 @@ else
     handles.DCM.xY.modality = mod;
 end
 
+if isequal(handles.DCM.xY.modality, 'LFP')
+    set(handles.Spatial, 'Value', strmatch('LFP', get(handles.Spatial, 'String')));
+end   
 
 % Assemble and display data
 %--------------------------------------------------------------------------
 handles = reset_Callback(hObject, eventdata, handles);
 try
     handles.DCM  = spm_dcm_erp_data(handles.DCM,handles.DCM.options.h);
-    spm_dcm_erp_results(handles.DCM, 'Data');
+    if isfield(handles.DCM.xY, 'xy')
+        spm_dcm_erp_results(handles.DCM, 'Data');
+    else
+        spm_dcm_ind_results(handles.DCM, 'Wavelet');
+    end  
     set(handles.dt, 'String',sprintf('bins: %.1fms', handles.DCM.xY.dt*1000))
     set(handles.dt, 'Visible','on')
     set(handles.data_ok, 'enable', 'on'); 
@@ -419,7 +430,11 @@ function Y_Callback(hObject, eventdata, handles)
 handles = reset_Callback(hObject, eventdata, handles);
 try
     DCM  = spm_dcm_erp_data(handles.DCM,handles.DCM.options.h);
-    spm_dcm_erp_results(DCM, 'Data');
+    if isfield(DCM.xY, 'xy')
+        spm_dcm_erp_results(DCM, 'Data');
+    else
+        spm_dcm_ind_results(DCM, 'Wavelet');
+    end  
     set(handles.dt, 'String',sprintf('bins: %.1fms', DCM.xY.dt*1000))
     set(handles.dt, 'Visible','on')
     set(handles.data_ok, 'enable', 'on'); 
@@ -536,8 +551,10 @@ set(handles.spatial_ok,    'Enable', 'on');
 switch handles.DCM.options.analysis
     case{'SSR','CSD'}
         set(handles.onset, 'Enable', 'off');
+        set(handles.dur,   'Enable', 'off');
     otherwise
         set(handles.onset, 'Enable', 'on');
+        set(handles.dur,   'Enable', 'on');
 end
 
  
@@ -570,7 +587,7 @@ switch DCM.options.spatial
         tmp       = get(handles.Slocation, 'String');
         if ~isempty(tmp) && size(tmp,1) == Nareas
             for i = 1:Nareas
-                tmp2 = str2num(tmp(i, :));
+                tmp2 = str2num(char(tmp(i, :)));
                 if length(tmp2) ~= 3
                     errordlg(sprintf('coordinates of source %d invalid',i));
                     return;
@@ -592,13 +609,16 @@ switch DCM.options.spatial
         DCM.Lpos = Slocation';
         
         % forward model (spatial)
-        %--------------------------------------------------------------------------
+        %------------------------------------------------------------------
         DCM = spm_dcm_erp_dipfit(DCM);
         set(handles.plot_dipoles,'enable','on')
  
     case{'LFP'}
           
-        if ~isdeployed, addpath(fullfile(spm('Dir'),'toolbox','Neural_Models')); end
+        if ~isdeployed, 
+            addpath(fullfile(spm('Dir'),'toolbox','Neural_Models'));
+        end
+        
         % for LFP
         %------------------------------------------------------------------
         DCM.Lpos = zeros(3,0);
@@ -621,6 +641,7 @@ set(handles.Spatial,          'Enable', 'off');
 set(handles.data_ok,          'Enable', 'off');
 set(handles.spatial_ok,       'Enable', 'off');
 set(handles.onset,            'Enable', 'off');
+set(handles.dur,              'Enable', 'off');
 set(handles.Sname,            'Enable', 'off');
 set(handles.Slocation,        'Enable', 'off');
 set(handles.spatial_back,     'Enable', 'off');
@@ -656,6 +677,7 @@ function spatial_back_Callback(hObject, eventdata, handles)
 set(handles.Spatial,      'Enable', 'off');
 set(handles.spatial_ok,   'Enable', 'off');
 set(handles.onset,        'Enable', 'off');
+set(handles.dur,          'Enable', 'off');
 set(handles.Sname,        'Enable', 'off');
 set(handles.Slocation,    'Enable', 'off');
 set(handles.spatial_back, 'Enable', 'off');
@@ -687,7 +709,7 @@ tmp       = get(handles.Slocation, 'String');
 Slocation = [];
 if ~isempty(tmp) 
     for i = 1:size(tmp, 1)
-        tmp2 = str2num(tmp(i, :))';
+        tmp2 = str2num(char(tmp(i, :)))';
         if length(tmp2) == 3
             Slocation = [Slocation tmp2];
         end
@@ -950,6 +972,7 @@ set(handles.Rft,               'Enable', 'off');
 set(handles.Spatial,           'Enable', 'on');
 set(handles.spatial_ok,        'Enable', 'on');
 set(handles.onset,             'Enable', 'on');
+set(handles.dur,               'Enable', 'on');
 set(handles.Sname,             'Enable', 'on');
 set(handles.Slocation,         'Enable', 'on');
 set(handles.spatial_back,      'Enable', 'on');
@@ -957,8 +980,10 @@ set(handles.spatial_back,      'Enable', 'on');
 switch handles.DCM.options.analysis
     case{'SSR','CSD'}
         set(handles.onset,     'Enable', 'off');
+        set(handles.dur,       'Enable', 'off');
     otherwise
         set(handles.onset,     'Enable', 'on');
+        set(handles.dur,       'Enable', 'on');
 end
  
 % connection buttons
@@ -1178,6 +1203,7 @@ switch handles.DCM.options.analysis
             'Input',
             'Response',
             'Response (image)',
+            'Scalp maps',
             'Dipoles'};
         try
             set(handles.Nmodes, 'Value', handles.DCM.options.Nmodes);
@@ -1185,11 +1211,12 @@ switch handles.DCM.options.analysis
             set(handles.Nmodes, 'Value', 8);
         end
         
-        set(handles.text20, 'String', 'modes');
+        set(handles.text20,     'String', 'modes');
         set(handles.model,      'Enable','on');
         set(handles.Spatial,    'String',{'IMG','ECD','LFP'});
         set(handles.Wavelet,    'Enable','off','String','-');
         set(handles.onset,      'Enable','on');
+        set(handles.dur,        'Enable','on');
         
     % Cross-spectral density model (complex)
     %----------------------------------------------------------------------
@@ -1220,6 +1247,7 @@ switch handles.DCM.options.analysis
         set(handles.Spatial,'String',{'IMG','ECD','LFP'});
         set(handles.Wavelet,'Enable','on','String','Spectral density');
         set(handles.onset,  'Enable','off');
+        set(handles.dur,    'Enable','off');
 
  
     % Cross-spectral density model (steady-state responses)
@@ -1245,6 +1273,7 @@ switch handles.DCM.options.analysis
         set(handles.Spatial,    'String',{'IMG','ECD','LFP'});
         set(handles.Wavelet,    'Enable','on','String','Spectral density');
         set(handles.onset,      'Enable','off');
+        set(handles.dur,        'Enable','off');
         
     % induced responses
     %----------------------------------------------------------------------
@@ -1259,6 +1288,7 @@ switch handles.DCM.options.analysis
             'Coupling (B - modes)'
             'Input (C - Hz)'
             'Input (u - ms)'
+            'Input (C x u)'
             'Dipoles'
             'Save results as img'};
         try
@@ -1269,13 +1299,14 @@ switch handles.DCM.options.analysis
         
         set(handles.text20, 'String', 'modes');
         set(handles.model,      'Enable','off');
-        if get(handles.Spatial, 'Value')>2
+        if get(handles.Spatial, 'Value') > 2
             set(handles.Spatial, 'Value', 2);
         end
         set(handles.Spatial,    'String',{'ECD','LFP'});
         set(handles.Wavelet,    'Enable','on','String','Wavelet transform');
         set(handles.Imaging,    'Enable','off' )
         set(handles.onset,      'Enable','on');
+        set(handles.dur,        'Enable','on');
         
     case{'PHA'}
           Action = {
@@ -1301,7 +1332,8 @@ switch handles.DCM.options.analysis
         set(handles.Spatial, 'String',{'ECD','LFP'});
         set(handles.Wavelet, 'Enable','on','String','Hilbert transform');
         set(handles.Imaging, 'Enable','off' )
-        set(handles.onset,   'Enable','off');    
+        set(handles.onset,   'Enable','off');
+        set(handles.dur,   'Enable','off');
         
     otherwise
         warndlg('unknown analysis type')
@@ -1369,7 +1401,7 @@ end
 guidata(hObject,handles);
 
 % --- Executes on button press in priors.
-function priors_Callback(hObject, eventdata, handles);
+function priors_Callback(hObject, eventdata, handles)
 handles = reset_Callback(hObject, eventdata, handles);
 spm_api_nmm(handles.DCM)
 
